@@ -76,14 +76,14 @@ LearnerClassifRanger = R6Class("LearnerClassifRanger",
         write.forest                 = p_lgl(default = TRUE, tags = "train")
       )
 
-      ps$values = list(num.threads = 1L)
+      ps$set_values(num.threads = 1L)
 
       super$initialize(
         id = "classif.ranger",
         param_set = ps,
         predict_types = c("response", "prob"),
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
-        properties = c("weights", "twoclass", "multiclass", "importance", "oob_error", "hotstart_backward", "missings"),
+        properties = c("weights", "twoclass", "multiclass", "importance", "oob_error", "hotstart_backward", "missings", "selected_features"),
         packages = c("mlr3learners", "ranger"),
         label = "Random Forest",
         man = "mlr3learners::mlr_learners_classif.ranger"
@@ -116,6 +116,14 @@ LearnerClassifRanger = R6Class("LearnerClassifRanger",
         stopf("No model stored")
       }
       self$model$prediction.error
+    },
+
+    #' @description
+    #' The set of features used for node splitting in the forest.
+    #'
+    #' @return `character()`.
+    selected_features = function() {
+      ranger_selected_features(self)
     }
   ),
 
